@@ -1,5 +1,5 @@
 package MIDI::Simple::Drummer::Rock;
-our $VERSION = '0.01';
+our $VERSION = '0.0101';
 use strict;
 use warnings;
 use base 'MIDI::Simple::Drummer';
@@ -106,43 +106,45 @@ sub _default_patterns {
 }
 
 1;
+
 __END__
 
+=pod
+
+=head1 NAME
+
+MIDI::Simple::Drummer::Rock
+
+=head1 VERSION
+
+version 0.03
+
+=head1 DESCRIPTION
+
+This package contains a collection of common rock patterns, loaded by
+L<MIDI::Simple::Drummer>.
+
 =head1 NAME
 
 MIDI::Simple::Drummer::Rock - Rock drum grooves
 
-=head1 DESCRIPTION
-
-This package contains a collection of patterns, loaded by
-L<MIDI::Simple::Drummer>.
-
-=head1 METHODS
-
-=head2 _default_patterns()
-
-  my $patterns = $self->_default_patterns();
-
-Return a hash-reference of named code-references, that define the
-patterns we can play.
-
 =head1 TO DO
 
-* Make cooler fills, Man.
+* "Do some cooler fills, Man."
 
 =head1 SEE ALSO
 
-L<MIDI::Simple::Drummer>
+L<MIDI::Simple::Drummer>, the F<eg/> and F<t/> test scripts.
 
-=head1 AUTHOR AND COPYRIGHT
+=head1 AUTHOR
 
-Gene Boggs E<lt>gene@cpan.orgE<gt>
+Gene Boggs <gene@cpan.org>
 
-Copyright 2010, Gene Boggs, All Rights Reserved.
+=head1 COPYRIGHT AND LICENSE
 
-=head1 LICENSE
+This software is copyright (c) 2013 by Gene Boggs.
 
-This program is free software; you can redistribute or modify it
-under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
